pub struct PointsGrantedDetail {
pub points_number: Option<i32>,
pub points_monetary_value: Option<Box<Money>>,
}Expand description
PointsGrantedDetail : The number of Amazon Points offered with the purchase of an item, and their monetary value.
Fields
points_number: Option<i32>The number of Amazon Points granted with the purchase of an item.
points_monetary_value: Option<Box<Money>>Implementations
sourceimpl PointsGrantedDetail
impl PointsGrantedDetail
sourcepub fn new() -> PointsGrantedDetail
pub fn new() -> PointsGrantedDetail
The number of Amazon Points offered with the purchase of an item, and their monetary value.